

set frame OPT_MISC
set frametitle "Option Selection Frame"
set icontitle "OptSel"


proc set-eg-option {k v} {
   global env
   set ll {}
   foreach p $env(EGOPTIONS) {
      if {[first $p]!=$k} then {lappend ll $p}
      }
   lappend ll [list $k $v]
   set env(EGOPTIONS) $ll
   }

proc edit-defaults {key stuff} {
   global debug
   if $debug then {puts stdout $key; puts stdout $stuff}
   set lines [load-defaults]
   set range [find-keyword $lines $key]
   if {[llength $range]==0} then \
      {save-defaults [linsert $lines [llength $lines] "## $key\n$stuff"]}\
   else \
      {save-defaults [lreplace $lines [first $range] [second $range] "## $key\n$stuff"]}
   }

proc load-defaults {} {
   global env
   set z [catch {set f [open ~/.eg-defaults.tcl r]}]
   if $z!=0 then {return [list "# eg-session defaults for user $env(USER)" ""]}
   set lines [split [read $f] "\n"]
   close $f   
   return $lines
   }

proc save-defaults {lines} {
   set f [open ~/.eg-defaults.tcl w]
   puts $f [join $lines "\n"]
   close $f   
   }

proc find-keyword {lines key} {
   set i 0; set found 0
   foreach l $lines {
      switch $found {
      0 {if {[string first "## $key" $l]==0} then {set start $i; set found 1}}
      1 {if {[string first "##" $l]==0} then {set finish $i; set found 2}}
      2 {break}
        }
     incr i
     }
   if $found==0 then {return {}}
   if $found==1 then {return [list $start [expr $i-1]]}
   if $found==2 then {return [list $start [expr $finish-1]]}
   }

proc lookup {k ps} {
   foreach p $ps {
      if {[first $p]==$k} then {return [second $p]}
   }
   error "keyword $k not in dictionary \{$ps\}" 
}


proc make-frame {} {

  :set footer_position center
  :frame [self frame-name] :label "[self frame-title]" :show-footer T  \
    :icon-name "[self icon-title]"

  :panel P :layout T :padx 10 :pady 10
   :layout H; :row-gap 10

    set printer        [get-eg-option printer]
    set printernames   [get-eg-option printernames]
    set printermenu {}
    foreach item $printernames {lappend printermenu [first $item]}
    set printername    [catch {lookup $printer $printernames}]
    set printercommand [get-eg-option printtemplate]

#     Printer Option

    :message    M11   :label "Printing" :bold T
    :hskip 20
    :text       T11   :label "Default Printer" :w 20 :value "$printer"
    :menubutton MENU1 :label "Printers" :strings $printermenu
#    :message    M12   :label "$printername" :w 20
    :row-gap 10; :next-row T
    :hskip 75
    :text       T12   :label "Print Command" :w 20 :value "$printercommand"

  :panel CLICK :layout T  :padx 10
    :layout H; :col-gap 20

    :button RESTORE  :label "Restore Settings"
    :button SAVE     :label "Save Settings as default"

    :next-row T
    :hskip 20
    :button REDISPLAY :label "Redisplay"

  :show T

}

proc click-printer-menu {v} {
  set printernames [get-eg-option printernames]
  set printer [first [lindex $printernames $v]]
#  set printername [second $v]
  set printername $printer
  :modify T11 :value "$printer"
#  :modify M12 :label "$printername"
  set-eg-option printer $printer
}

proc click-printer-command {v} {
  set printercommand $v
  set-eg-option printtemplate $printercommand
}

proc click-printers {v} {
}

proc ex-click-printers {v} {
  set printer [first $v]
#  set printername [second $v]
  set printername $printer
  :modify T11 :value "$printer"
#  :modify M12 :label "$printername"
  set-eg-option printer $printer
  
  set printernames [get-eg-option printernames]
  lappend printernames "$v $v"
  set-eg-option printernames $printernames
  set printermenu {}
  foreach item $printernames {lappend printermenu [first $item]}
  :modify MENU1 :strings $printermenu
}

proc click-save {} {

    set printer        [get-eg-option printer]
#    set printernames   [get-eg-option printernames]
    set printercommand [get-eg-option printtemplate]

   edit-defaults  printer        "set-eg-option printer $printer"
#   edit-defaults  printernames   "set-eg-option printernames \{$printernames\}"
   edit-defaults  printercommand "set-eg-option printtemplate \{$printercommand\}"

  redisplay
}

proc redisplay {} {make-frame}

proc click arg {
   global debug

   if {$debug} then {insert-debug "click with argument \{$arg\}"}
   set f [lindex $arg 0]
   set c [lindex $arg 1]
   set w [lindex $arg 2]
   set v [lindex $arg 3]
   if {$c==":quit"} then {click-quit; return}
   switch $w {

      MENU1     {click-printer-menu [lindex $arg 4]}
      T11       {click-printers $v}
      T12       {click-printer-command $v}

      RESTORE   {send root exec-defaults; redisplay}
      SAVE      {click-save}

      REDISPLAY {redisplay}

      default   {}
   }
}
